/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.ActivityManager.ActivityRanking.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef ACTIVITYRANKINGINTERFACE_H
#define ACTIVITYRANKINGINTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "ActivityData.h"

/*
 * Proxy class for interface org.kde.ActivityManager.ActivityRanking
 */
class OrgKdeActivityManagerActivityRankingInterface: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.kde.ActivityManager.ActivityRanking"; }

public:
    OrgKdeActivityManagerActivityRankingInterface(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~OrgKdeActivityManagerActivityRankingInterface();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<ActivityDataList> activities()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("activities"), argumentList);
    }

    inline QDBusPendingReply<> test()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("test"), argumentList);
    }

    inline QDBusPendingReply<QStringList> topActivities()
    {
        QList<QVariant> argumentList;
        return asyncCallWithArgumentList(QStringLiteral("topActivities"), argumentList);
    }

Q_SIGNALS: // SIGNALS
    void rankingChanged(const QStringList &topActivities, ActivityDataList activities);
};

namespace org {
  namespace kde {
    namespace ActivityManager {
      using ActivityRanking = ::OrgKdeActivityManagerActivityRankingInterface;
    }
  }
}

#endif
